.. include:: ../../README.rst

Contents:

.. toctree::
   introduction
   usage
   fields
   threads
   development
   :maxdepth: 2


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

